Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TranslateState ¶
Types ¶
type Properties ¶
type Properties struct {
// contains filtered or unexported fields
}
func New ¶
func New(config *Config) (*Properties, error)
func (*Properties) Get ¶
func (p *Properties) Get() ([]*Data, error)
func (*Properties) Migrate ¶
func (p *Properties) Migrate() error
func (*Properties) Rollback ¶
func (p *Properties) Rollback(steps int) error
type State ¶
type State uint16
const ( UnknownState State = 0 //PendingState means that migration has not been applied yet. PendingState State = 1 << (iota - 1) //SuccessState means that migration is succeeded. SuccessState //IgnoredState means that migration will not be considered when running migrate. IgnoredState //AvailableState means that backward migration is ready to be applied if desired. AvailableState //UndoneState means that migration is succeeded but has since been undone. UndoneState //MissingState means that migration has been succeeded/failed but could not be resolved. MissingState //FailedState means that migration is failed. FailedState //FutureState means that migration has been succeeded/failed and its version is higher //than the one listed on schema history table. FutureState //OutdatedState is a repeatable migration that is outdated and should be re-applied OutdatedState //SupersededState is a repeatable migration that is outdated and has already been //superseded by a newer one SupersededState )
Click to show internal directories.
Click to hide internal directories.